The way of the program
:::::::::::::::::::::::

.. toctree::
   :maxdepth: 3

   the_way.rst
   programming_language.rst
   program.rst
   debugging.rst
   formal_natural.rst
   first_program.rst
   glossary.rst
   Exercises.rst
